@@ -8,7 +8,7 @@ function(Ns, q, Tree, Normalize = TRUE, Correction = "Best", CheckArguments = TR
   Entropy <- PhyloApply(Tree, bcTsallis, Ns, Normalize, q=q, Correction=Correction, CheckArguments=FALSE)
   # Complete it
   Entropy$Function <- "PhyloEntropy" 
-  Entropy$Distribution <- deparse(substitute(Ps)) 
+  Entropy$Distribution <- deparse(substitute(Ns)) 
   Entropy$Tree <- deparse(substitute(Tree))
   Entropy$Type <- "alpha or gamma"
   Entropy$Order <- q
